Method: ContentDm::Record#to_xml

Defined in:
lib/contentdm/record.rb

#to_xml(opts = {}) ⇒ Object

Serialize the Record to a Qualified Dublin Core XML string. If a Mapper has been initialized for the Record’s owning collection, it will be used. Otherwise, the GenericMapper will be used.



72
73
74
# File 'lib/contentdm/record.rb', line 72

def to_xml(opts = {})
  mapper.to_xml(self, opts)
end